%global prerel	beta

# If we want to disable tests
%bcond_without	check

# Don't create docs (unless we want to)
%bcond_without	docs

Name:		 nanomsg
Version:	 0.9
Release:	 0.1.%{prerel}%{?dist}
Summary:	 A fast, scalable, and easy to use socket library

Group:		 System Environment/Libraries
License:	 MIT
URL:		 http://nanomsg.org/
Source0:	 https://github.com/nanomsg/nanomsg/archive/%{version}-%{prerel}/%{name}-%{version}-%{prerel}.tar.gz

# Patches backported from upstream
Patch0:	  	0001-fixes-728-source-archives-missing-version.patch

# Patches to prepare for upstream submission
# Remove conflicting attribute from CMakeLists for library target
Patch100:	nanomsg-0.9-rm-version-property.patch

BuildRequires: cmake >= 2.8.7

%if %{with docs}
BuildRequires: asciidoc xmlto
BuildRequires: rubygem(asciidoctor)
%endif

%description
nanomsg is a socket library that provides several common communication 
patterns. It aims to make the networking layer fast, scalable, and easy 
to use. Implemented in C, it works on a wide range of operating systems 
with no further dependencies.

The communication patterns, also called "scalability protocols", are 
basic blocks for building distributed systems. By combining them you can 
create a vast array of distributed applications.


%package	devel
Summary:	Development files for the nanomsg socket library
Group:		Development/Libraries
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description 	devel
This package contains files needed to develop applications using nanomsg, 
a socket library that provides several common communication patterns.


%package	utils
Summary:	Command line interfaces for communicating with nanomsg
Group:		Applications/Internet

%description	utils
Includes nanocat, a simple utility for reading and writing to nanomsg 
sockets and bindings, which can include local and remote connections.

nanocat can change its behavior based on how it is called, and several
symlinks are provided.

%if %{with docs}
%package	doc
Summary:	HTML Documentation for nanomsg
Group:		Documentation
Requires:	%{name}-devel = %{version}-%{release}

%description	doc
Contains HTML versions of the documentation for development of nanomsg-
related software.
%endif


%prep
%setup -q -n %{name}-%{version}-%{prerel}
%autopatch -p1

%build
%cmake . -DNN_ENABLE_DOC:BOOL=%{?_with_docs:ON}%{?!_with_docs:OFF}

%make_build V=1


%install
%make_install

%if %{with docs}
# remove docs (they'll be re-added via macro later on)
rm -fR %{buildroot}%{_defaultdocdir}
%endif

# conditional for enabling/disabling tests
%if %{with check}
%check
export LD_LIBRARY_PATH="%{buildroot}%{_libdir}"
ctest .
%endif


%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig


%files
%defattr(-,root,root)
%license COPYING
%doc README
%{_libdir}/*.so.*


%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%files utils
%defattr(-,root,root)
%{_bindir}/*

%if %{with docs}
%files doc
%defattr(-,root,root)
%license COPYING
%doc AUTHORS README
%doc doc/*
%endif

%changelog
* Thu Jun  2 2016 Neal Gompa <ngompa13@gmail.com> - 0.9-0.1.beta
- Update to 0.9-beta release
- Backport patch to fix missing version
- Add patch to fix build of library

* Wed Nov 25 2015 Neal Gompa <ngompa13{%}gmail{*}com> - 0.8-0.1.beta
- Update to 0.8-beta release
- Drop cruft related to supporting EL6 and older

* Tue Oct 27 2015 Japheth Cleaver <cleaver@terabithia.org> 0.7-0.1.beta
- update to 0.7-beta release

* Fri Nov 14 2014 Japheth Cleaver <cleaver@terabithia.org> 0.5-0.1.beta
- update to 0.5-beta release

* Sun Jul 27 2014 Japheth Cleaver <cleaver@terabithia.org> 0.4-0.3.beta
- compile with correct Fedora flags
- move documentation back to base package
- spec file cleanups

* Thu Jul 17 2014 Japheth Cleaver <cleaver@terabithia.org> 0.4-0.2.beta
- drop the 'lib' prefix from package name
- remove explicit pkgconfig requires in nanomsg-devel
- move overview man pages to devel subpackage
- move html to doc subpackage

* Thu Jul 17 2014 Japheth Cleaver <cleaver@terabithia.org> 0.4-0.1.beta
- new "libnanomsg" package based on BZ#1012392, with current versioning
- devel and utils subpackages created, static lib a build conditional
- check section added as a build conditional
- ensure man pages for nanocat symlinks present
- disable RPATH in library
- License set to MIT
